package model.fish.behavior;

import model.ILambda;
import sysModel.fish.Fish;
import sysModel.fish.IFishBehavior;

/**
 * A fish that swims around in a circle.
 *
 * @author Mathias Ricken
 */
public class CircleBehavior implements IFishBehavior {
    /**
     * Carry out movement behavior for the host fish.
     *
     * @param host fish to move.
     */
    public void move(final Fish host) {
        // attempt to move forward
        host.tryMoveFwd(new ILambda() {
            public Object apply(Object param) {
                // the field ahead is blocked, turn around
                host.turnRight(Math.PI);
                return null;
            }
        },
            new ILambda() {
                public Object apply(Object param) {
                    // the field ahead is open, move
                    ((ILambda)param).apply(null);
                    // turn 10 degrees to the right
                    host.turnRight(Math.PI / 18);
                    return null;
                }
            });

    }

    /**
     * Private singleton ctor.
     */
    private CircleBehavior() {
    }

    /**
     * Singleton instance.
     */
    public static final CircleBehavior Singleton = new CircleBehavior();
}
