package model.fish.behavior;

import model.ILambda;
import sysModel.fish.Fish;
import sysModel.fish.IFishBehavior;

/**
 * Class for a darter fish.
 *
 * @author Mathias G. Ricken
 */
public class DarterBehavior implements IFishBehavior {
    /**
     * Carry out movement behavior for the host fish.
     *
     * @param host fish to move.
     */
    public void move(final Fish host) {
        // attempt to move forward
        host.tryMoveFwd(new ILambda() {
            public Object apply(Object param) {
                // could not move forward at all
                // turn PI radians
                host.turnRight(Math.PI);
                return null;
            }
        },
            new ILambda() {
                public Object apply(Object param) {
                    // the field ahead is open, move
                    ((ILambda)param).apply(null);
                    // attempt to move forward again
                    host.tryMoveFwd(new ILambda() {
                        public Object apply(Object param) {
                            // could not move forward any more
                            // do nothing
                            return null;
                        }
                    },
                        new ILambda() {
                            public Object apply(Object param) {
                                // second field ahead is open, move
                                ((ILambda)param).apply(null);
                                return null;
                            }
                        });
                    return null;
                }
            });
    }

    /**
     * Private singleton ctor.
     */
    private DarterBehavior() {
    }

    /**
     * Singleton instance.
     */
    public static final DarterBehavior Singleton = new DarterBehavior();

}
