package model.fish.behavior;

import model.ILambda;
import sysModel.fish.Fish;
import sysModel.fish.IFishBehavior;

/**
 * A simple fish that swims back and forth.
 *
 * @author Mathias Ricken
 */
public class SimpleBehavior implements IFishBehavior {
    /**
     * Carry out movement behavior for the host fish.
     *
     * @param host fish to move.
     */
    public void move(final Fish host) {
        // attempt to move forward
        host.tryMoveFwd(new ILambda() {
            public Object apply(Object param) {
                // cannot move
                // turn PI radians
                host.turnRight(Math.PI);
                return null;
            }
        }, new ILambda() {
            public Object apply(Object param) {
                // can move forward, do it
                ((ILambda)param).apply(null);
                return null;
            }
        });
    }

    /**
     * Private singleton ctor.
     */
    private SimpleBehavior() {
    }

    /**
     * Singleton instance.
     */
    public static final SimpleBehavior Singleton = new SimpleBehavior();

}
